@@ -140,12 +140,21 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
         name='projectReferences',
         widget=ReferenceBrowserWidget(
             label=_(u'Reference Files'),
+            restrict_browsing_to_startup_directory=False,
+            #base_query={'path': '/intranet/project-database/'},
+            show_indexes=True,
+            allow_browse=False,
+            #startup_directory='/intranet/project-database/',
+            #show_results_without_query=False,
+            available_indexes={'Title':'Title', 'SearchableText': 'Text in Document'},
+            default_search_index='Title'
       ),
       required=False,
       searchable=False,
       multiValued=True,
       allow_sorting=True,
       relationship='WorksWith',
+
       allowed_types=('Document','File','Image','Folder')
     )
 
